Learn R Programming

afmpar (version 0.2.0)

pa_check: Check validity of PA

Description

Given a character vector, for each of its elements, check the validity of the Greek Personal Number (PA). The PA allows numeric digits 0-9 and the uppercase Latin letters whose uppercase glyphs are the same in the Greek and Latin alphabet (ABEZHIKMNOPTYX).

Usage

pa_check(v)

Value

A logical vector.

Arguments

v

a character vector for whose elements validity of PA is checked.

Examples

Run this code
pa_check("ABYBADAFM999")
pa_check("ABY123456789")
pa_check("ABY12345678")
pa_check("ABY1234567890")
pa_check("5XY123456783")
pa_check(c("ABY123456789", "PTT111111114"))

Run the code above in your browser using DataLab