Given a character vector, for each of its elements,
check the validity of the Greek Personal Number (PA).
The PA allows numeric digits 0-9 and the
uppercase Latin letters whose uppercase
glyphs are the same in the Greek and Latin alphabet
(ABEZHIKMNOPTYX).
Usage
pa_check(v)
Value
A logical vector.
Arguments
v
a character vector for whose elements validity of PA
is checked.